# xprint

## Development Environment

- Windows 10
- Python 3.7.0

## Installation

```
$ pip3 install xprint
```

## Usage

```
import xprint as xp
xp.init()

xp.success()
xp.error()
xp.value()
xp.step()
xp.job()
xp.about_t()
xp.about_to()
xp.getting()
...
```
